@@ -1,17 +1,33 @@
 #!/usr/bin/env python3
-import os
-import subprocess
+import signal
 import sys
+import time
 
 from oort.shared.config import get_config_upload_folder_sections, get_logger
 from oort.shared.identity import Identity
 from oort.uploader.engine.pathsobserver import PathsObserver
+from oort.uploader.engine.zipper import zipper_stop_event
 
 paths_observer = PathsObserver()
 
+logger = get_logger()
+
+
+def handle_ctrl_c(signum, frame):
+    logger.info(f'Interrupt received: {signum}. Cancelling all zips.')
+    zipper_stop_event.set()
+    time.sleep(0.1)
+    sys.exit(0)
+
+
+# Beware only the main thread of the main interpreter is allowed to set a new signal handler.
+# https://docs.python.org/3/library/signal.html
+signal.signal(signal.SIGINT, handle_ctrl_c)  # Handle ctrl-c
+signal.signal(signal.SIGQUIT, handle_ctrl_c)  # Handle ctrl-\
+signal.signal(signal.SIGTERM, handle_ctrl_c)
+
 if __name__ == "__main__":
     debug = len(sys.argv) > 1 and sys.argv[1] in ['-d', '--debug']
-    logger = get_logger(debug=debug)
     paths_observer.debug = debug
 
     logger.info('Starting infinite loop of PathsObserver...')
